IF OBJECT_ID('trg_Publication_Priznaci_Delete') IS NOT NULL
			DROP TRIGGER trg_Publication_Priznaci_Delete
GO


CREATE  TRIGGER trg_Publication_Priznaci_Delete ON dbo.Publication 
FOR DELETE
AS
/*------------------------------------------------------------------------

	imPress Manager Project
	Copyright (c) 2000-2002 UniCont Soft

	Trigger za iztriwane na priznak pri iztriwane na izdanie

	Modifications: 
	  20020320	WQW	Initial implementation

*/------------------------------------------------------------------------
SET			NOCOUNT ON

DELETE 		m_Pr 
FROM 		m_Pr p 
JOIN		deleted d
ON			p.ID = d.ID

GO


IF OBJECT_ID('trg_Publication_Priznaci_Update') IS NOT NULL
			DROP TRIGGER trg_Publication_Priznaci_Update
GO


CREATE TRIGGER trg_Publication_Priznaci_Update 
			ON			dbo.Publication 
			FOR			INSERT, UPDATE
AS
/*------------------------------------------------------------------------
    imPress Manager
    Copyright (c) 2000-2002 UniCont Soft

         (m_PR)

    Modifications: 
	  2002-03-06 Rumen - Initial implementation
	  2002-03-20 WQW - fix SET NOCOUNT ON
*/------------------------------------------------------------------------
SET			NOCOUNT ON

-- insert actions - insert the new contragent in m_PR
INSERT INTO m_PR (ID
			, Code
			, Name
			, PrCategory_ID
			, Measure_ID
			, IsSystem)
SELECT 		i.ID
			, i.CODE
			, i.Name
			, 3 -- Produkti/materiali
			, i.Measure_ID
			, 0
FROM 		inserted i
LEFT JOIN 	m_PR m 
ON 			i.ID = m.ID
WHERE		m.ID IS NULL

--- update action
IF 			UPDATE(Name)
			OR UPDATE(Code)
			OR UPDATE(Measure_ID)
BEGIN
			UPDATE 		m_PR
			SET			Name = i.Name
						, Code = i.Code
						, Measure_ID = i.Measure_ID
			FROM 		inserted i
			JOIN 		m_PR m
			ON 			i.ID = m.ID
			WHERE		m.Name != i.Name
						OR COALESCE(m.Code, '') != COALESCE(i.Code, '')
						OR COALESCE(m.Measure_ID, '00000000-0000-0000-0000-000000000000') != COALESCE(i.Measure_ID, '00000000-0000-0000-0000-000000000000')
END
GO


IF OBJECT_ID('trg_Persons_Priznaci_Delete') IS NOT NULL
			DROP TRIGGER trg_Persons_Priznaci_Delete
GO

CREATE TRIGGER trg_Persons_Priznaci_Delete 
ON			cg_Persons
FOR			DELETE
AS
/*------------------------------------------------------------------------

	imPress Manager Project
	Copyright (c) 2000-2002 UniCont Soft

	Trigger za iztriwane na priznak pri iztriwane na persona

	Modifications: 
	  20020606	WQW	Initial implementation

*/------------------------------------------------------------------------
SET			NOCOUNT ON

DELETE 		m_Pr 
FROM 		m_Pr p 
JOIN		deleted d
ON			p.ID = d.ID
GO


IF OBJECT_ID('trg_Persons_Priznaci_Update') IS NOT NULL
			DROP TRIGGER trg_Persons_Priznaci_Update
GO

CREATE  TRIGGER trg_Persons_Priznaci_Update 
ON			cg_Persons
FOR			INSERT, UPDATE
AS
/*------------------------------------------------------------------------

    imPress Manager
    Copyright (c) 2000-2002 UniCont Soft

         (m_PR)

    Modifications: 
	  20020606	WQW 	Initial implementation

*/------------------------------------------------------------------------
SET			NOCOUNT ON

-- insert actions - insert the new contragent in m_PR
INSERT INTO m_PR (ID
			, Code
			, Name
			, PrCategory_ID
			, IsSystem)
SELECT 		i.ID
			, i.CODE
			, i.Name
			, 2 -- PrCat = 2: persona
			, 0
FROM 		inserted i
LEFT JOIN 	m_PR m 
ON 			i.ID = m.ID
WHERE		m.ID IS NULL

--- update modified
IF 			UPDATE(Code) 
			OR UPDATE(Name)
BEGIN
			UPDATE 		m_PR
			SET			Name = i.Name
						, PrCategory_ID = 2
						, Code = i.Code
			FROM 		inserted i
			JOIN 		m_PR m
			ON 			i.ID = m.ID
			WHERE		m.Name != i.Name
						OR m.Code != i.Code
						OR m.PrCategory_ID != 2
END

GO


IF OBJECT_ID('trg_Contragents_Priznaci_Delete') IS NOT NULL
			DROP TRIGGER trg_Contragents_Priznaci_Delete
GO

CREATE  TRIGGER trg_Contragents_Priznaci_Delete ON dbo.Contragents 
FOR DELETE
AS
/*------------------------------------------------------------------------

	imPress Manager Project
	Copyright (c) 2000-2002 UniCont Soft

	Trigger za iztriwane na priznak pri iztriwane na contragent

	Modifications: 
	  20020320	WQW	Initial implementation

*/------------------------------------------------------------------------
SET			NOCOUNT ON

DELETE 		m_Pr 
FROM 		m_Pr p 
JOIN		deleted d
ON			p.ID = d.ID
GO


IF OBJECT_ID('trg_Contragents_Priznaci_Update') IS NOT NULL
			DROP TRIGGER trg_Contragents_Priznaci_Update
GO

CREATE  TRIGGER [trg_Contragents_Priznaci_Update] ON dbo.Contragents 
FOR INSERT, UPDATE
AS
/*------------------------------------------------------------------------
    imPress Manager
    Copyright (c) 2000-2002 UniCont Soft

         (m_PR)

    Modifications: 
	  2002-03-06 Rumen - Initial implementation
	  2002-03-20 WQW - fix
*/------------------------------------------------------------------------
SET			NOCOUNT ON

-- insert actions - insert the new contragent in m_PR
INSERT INTO m_PR (ID
			, Code
			, Name
			, PrCategory_ID
			, IsSystem)
SELECT 		i.ID

			, i.CODE
			, i.Name
			, 1 -- PrCat = 1: contragent
			, 0
FROM 		inserted i
LEFT JOIN 	m_PR m 
ON 			i.ID = m.ID
WHERE		m.ID IS NULL

--- update modified
IF 			UPDATE(Code) 
			OR UPDATE(Type) 
			OR UPDATE([Name])
BEGIN
			UPDATE 		m_PR
			SET			[Name] = i.[Name]
						, [PrCategory_ID] = 1
						, Code = i.Code
			FROM 		inserted i
			JOIN 		m_PR m
			ON 			i.ID = m.ID
			WHERE		m.Name != i.Name
						OR m.Code != i.Code
						OR m.PrCategory_ID != 1
END


GO


IF OBJECT_ID('trg_accSaldoDreem_LinkedAcc_Delete') IS NOT NULL
			DROP TRIGGER trg_accSaldoDreem_LinkedAcc_Delete
GO

CREATE  TRIGGER 	trg_accSaldoDreem_LinkedAcc_Delete ON [dbo].[acc_SaldoDreem] 
FOR 	DELETE
AS
/*------------------------------------------------------------------------

	imPress Manager Project
	Copyright (c) 2000-2002 UniCont Soft

	Trigger za iztriwane na priznak pri iztriwane na contragent

	Modifications: 
	  2002-04-01	Rumen	Initial implementation

*/------------------------------------------------------------------------
SET			NOCOUNT ON

IF EXISTS(	SELECT 		*
			FROM 		acc_Main a
			JOIN 		deleted d
			ON 			d.ID = a.AccLink_ID)
BEGIN
			RAISERROR ('LINKED DOC ERROR', 16, 1)
			ROLLBACK TRAN
END
GO


IF OBJECT_ID('trg_accMain_LinkedAcc_Delete') IS NOT NULL
			DROP TRIGGER trg_accMain_LinkedAcc_Delete
GO

CREATE  TRIGGER 	trg_accMain_LinkedAcc_Delete ON [dbo].[acc_Main] 
FOR 	DELETE
AS
/*------------------------------------------------------------------------

	imPress Manager Project
	Copyright (c) 2000-2002 UniCont Soft

	Trigger za iztriwane na priznak pri iztriwane na contragent

	Modifications: 
	  2002-04-01	Rumen	Initial implementation

*/------------------------------------------------------------------------
SET			NOCOUNT ON

IF EXISTS(	SELECT 		*
			FROM 		acc_Main a
			JOIN 		deleted d
			ON 			d.ID = a.AccLink_ID)
BEGIN
			RAISERROR ('LINKED DOC ERROR', 16, 1)
			ROLLBACK TRAN
END
GO


